---
gitea: none
include_toc: true
---

# Hardware
## Specs
**BTT SKR Mini E3 V2.0, direct drive, and BL-Touch - Raspberry Pi 4 running Klipper & Fluidd**

I'm collecting information here to track progress on setting up an Ender 3 Pro that I pulled out of the trash. The previous owner had already upgraded the motherboard and completed a changeover to direct drive. The Z-axis was initially bizarrely overtightened, causing MAJOR skipping issues that squished all the prints about 30%.

After properly torquing the eccenctric nuts on the Z-axis and other belts as well as lubing everything, it printed okay! However, it had Merlin firmware which is poopy so now I'm working on converting it to Klipper. 

Before getting into the printer itself, let's go over how to connect to the Pi, which is running the whole show.

### Built Plates
I have two build plates for this. The stock one from Creality with the crappy magnet on the back that feels like an up-jumped refrigerator sticker, and a fancy-pants PEI sheet. 

The PEI sheet doesn't work for shit. It works beautifully on my other printers but on this one I genuinely can't get anything to stick to it. I'm certain it's either a bed leveling or Z offset issue, but the crappy sheet that came with the machine, all scratched to shit, works much, much better.

## Problems?
### Non-functional/detrimental bed meshes
Bed meshes don't seem to work properly. I can get wildly different bed meshes without ever moving or adjusting anything on the machine, leading me to believe that the BL-Touch probe might have some issues (or may not be a genuine part, I'm not certain.) It might be worth looking into something else for Z probing. 

### Bad PEI plate, maybe
I can't get anything to stick to the PEI plate I bought, which sucks because it's the ONLY build plate I bother using on other builds.

### No webcam
For whatever reason, I curently cannot get the webcam working.

# Raspberry Pi 4
**Overview**
<pre>
       _,met$$$$$gg.          <span style="color:#fd5c63"><b>ender</b></span>@<span style="color:#fd5c63"><b>ender3Pro</b></span> 
    ,g$$$$$$$$$$$$$$$P.       --------------- 
  ,g$$P"     """Y$$.".        <span style="color:#fd5c63"><b>OS:</b></span> Debian GNU/Linux 11 (bullseye) aarch64 
 ,$$P'              `$$$.     <span style="color:#fd5c63"><b>Host:</b></span> Raspberry Pi 4 Model B Rev 1.1 
',$$P       ,ggs.     `$$b:   <span style="color:#fd5c63"><b>Kernel:</b></span> 6.1.21-v8+ 
`d$$'     ,$P"'  <span style="color:red"> . </span>   $$$    <span style="color:#fd5c63"><b>Uptime:</b></span> 2 hours, 9 mins 
 $$P      d$'     <span style="color:red">,</span>    $$P    <span style="color:#fd5c63"><b>Packages:</b></span> 957 (dpkg) 
 $$:      $$.   <span style="color:red">-</span>    ,d$$'    <span style="color:#fd5c63"><b>Shell:</b></span> bash 5.1.4 
 $$;      Y$b._   _,d$P'      <span style="color:#fd5c63"><b>Terminal:</b></span> /dev/pts/2 
 Y$$.    <span style="color:red">`.</span>`"Y$$$$P"'         <span style="color:#fd5c63"><b>CPU:</b></span> BCM2835 (4) @ 1.500GHz 
 `$$b      <span style="color:red">"-.__</span>              <span style="color:#fd5c63"><b>Memory:</b></span> 157MiB / 3618MiB 
  `Y$$
   `Y$$.                                              
     `$$b.                                            
       `Y$$b.
          `"Y$b._
              `"""
</pre>

This machine is currently flashed with a Debian-based OS called MainsailOS - however, I do not like Mainsail so it has been gutted and replaced with Fluidd for the web interface. 

## Software

### Connecting to WiFi
On the <code>/boot/</code> partition of the SD card, create a plaintext file called <code>wpa_supplicant.conf</code> and use the following template to add the correct information for your WiFi network (this unit is compatible with both  2.4 and 5 GHz networks). Once you have created that file, re-insert the SD card (or reboot if edited in-place) and after about a minute it should appear on your WiFi network. DHCP is currently enabled. 

<pre>
# Simple configuration for a typical WPA2 network

ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
update_config=1
country=US # US Country code

network={
        scan_ssid=1
        ssid="<Name of your wireless LAN>"
        psk="<Password for your wireless LAN>"
        proto=RSN
        key_mgmt=WPA-PSK
        pairwise=CCMP
        auth_alg=OPEN
}
</pre>

### Remote administration
Credentials to SSH into the machine are as follows:
- User: <code>ender</code>
- Password: <code>1234</code>

#### Example
<pre>
<span style="color:green"><b>steeb@thinkpadz13:~$</b></span> ssh ender@192.168.50.222
ender@192.168.50.222's password: 
Linux ender3Pro 6.1.21-v8+ #1642 SMP PREEMPT Mon Apr  3 17:24:16 BST 2023 aarch64

The programs included with the Debian GNU/Linux system are free software;
the exact distribution terms for each program are described in the
individual files in /usr/share/doc/*/copyright.

Debian GNU/Linux comes with ABSOLUTELY NO WARRANTY, to the extent
permitted by applicable law.
Last login: Fri Aug  2 14:05:21 2024 from 10.6.0.2
<span style="color:lightgreen"><b>ender@ender3Pro:~ $</b></span>
</pre>

### KIAUH (Klipper Installation and Update Helper)

I have been managing additional package for the 3d printer-specific stuff using a utility called KIAUH. You can find the Git for them [here](https://github.com/dw-0/kiauh).

You can run it using the following command:
<pre>
./kiauh/kiauh.sh
</pre>

See the Git for documentation. You probably won't need to do much through this unless you're adding new features or want to try out Mainsail instead of Fluidd. Actual updating of things is handled through the Fluidd and/or Mainsail interface.

### Other

This is running a Debian-based OS. Because of this, you can update using <code>apt</code> just like on any other system. Everything that is currently installed is actively maintained and should work great through updates. On my other 2 printers running Debian w/ Klipper, updates have gone off without a hitch. 

# Firmware

The printer is running Klipper ([GitHub repo](https://github.com/Klipper3d/klipper)). There is a host component (setup on the Pi) and the firmware component - it does not work independtly, as a lot of the tuning and tweaking is stored on the host computer.

## Management
You can browse to the IP address of the printer in a web browser to get to the Fluidd interface - all management is done through there, including updates to Klipper and installed plugins. Any commands that are listed below need to be entered into the Console in the Fluidd interface - there's a small one on the main screen or a larger console window if you click it on the left-hand side of the window.

## Tuning
### Z Offset
[Official documentation link](https://www.klipper3d.org/Probe_Calibrate.html)

**NOTE:** I've hda to re-adjust the Z offset fairly frequently, sometimes between each print. It's not a large task, but I'm unsure if there's an issue with either the probe or the bed screws or the bed itself - just do not rely on this to be accurate over a large amount of time!

Home all axes and then enter <code>PROBE_CALIBRATE</code> into the command line. From there, adjust the Z offset in small increments using the on-screen arrows until it is close enough to the bed that you feel resistance when you drag a sheet of paper below it. You just need to feel enough drag to be noticable - it doesn't need to put up resistance

### Bed Leveling
[Official documentation link](https://www.klipper3d.org/Manual_Level.html)

Once the Z offset is set, you can now manually level the be by entering <code>BED_SCREWS_ADJUST</code> into the command line. The machine will then go to each corner one-by-one while you adjust the screw knobs and repeat the paper test, like in the Z offset section. If you need to make an adjustment to the screw (more than 1/8 of a turn), click "Adjustment", if the setting is fine, click "Accept" - once you accept all four corners in a row, the bed is leveled.

## Bed Mesh Calibration
[Official documentation link](https://www.klipper3d.org/Bed_Mesh.html)

**NOTE:** I'm not certain this is 100% necessary as this unit appears to have a pretty dang flat bed; my results have not been much different when using a bed mesh. I feel that the BL Touch probe installed is either wonky or inaccurate. If and when I switch this machine over to hard mounts, this may be a more important set.

